package dev.kske.chess.ui;

import java.awt.Color;
import java.awt.Graphics;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JComponent;

import dev.kske.chess.board.Position;

/**
 * Project: <strong>Chess</strong><br>
 * File: <strong>OverlayComponent.java</strong><br>
 * Created: <strong>08.07.2019</strong><br>
 * Author: <strong>Kai S. K. Engelbart</strong>
 */
public class OverlayComponent extends JComponent {

	private static final long serialVersionUID = -7326936060890082183L;

	private final BoardPane boardPane;

	private List<Position>	dots;

	public OverlayComponent(BoardPane boardPane) {
		this.boardPane = boardPane;
		setSize(boardPane.getPreferredSize());
		dots			= new ArrayList<>();
	}

	@Override
	protected void paintComponent(Graphics g) {
		super.paintComponent(g);

		final int tileSize = getTileSize();
		
		// Draw possible moves if a piece was selected
		if (!dots.isEmpty()) {
			g.setColor(Color.green);
			int radius = tileSize / 4;
			for (Position dot : dots)
				g.fillOval(dot.x * tileSize + tileSize / 2 - radius / 2,
						dot.y * tileSize + tileSize / 2 - radius / 2,
						radius,
						radius);
		}
	}

	public void displayDots(List<Position> dots) {
		this.dots.clear();
		this.dots.addAll(dots);
		repaint();
	}

	public void clearDots() {
		dots.clear();
		repaint();
	}

	public int getTileSize() { return boardPane.getTileSize(); }
}
