package dev.kske.chess.ui;

import java.awt.Image;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.imageio.ImageIO;

import dev.kske.chess.board.Piece;

/**
 * Project: <strong>Chess</strong><br>
 * File: <strong>TextureUtil.java</strong><br>
 * Created: <strong>01.07.2019</strong><br>
 * Author: <strong>Kai S. K. Engelbart</strong>
 */
public class TextureUtil {

	private static Map<String, Image> textures;

	static {
		textures = new HashMap<>();
		loadPieceTextures();
	}

	private TextureUtil() {}

	/**
	 * Loads a piece texture fitting to a piece object
	 * 
	 * @param piece The piece from which the texture properties are taken
	 * @return The fitting texture
	 */
	public static Image getPieceTexture(Piece piece) {
		String key = piece.getType().toString().toLowerCase() + "_" + piece.getColor().toString().toLowerCase();
		return textures.get(key);
	}

	/**
	 * Scales all piece textures to fit the current tile size
	 */
	public static void scalePieceTextures(int scale) {
		textures.replaceAll((key, img) -> img.getScaledInstance(scale, scale, Image.SCALE_SMOOTH));
	}

	/**
	 * Loads an image from a file.
	 * 
	 * @param file The image file
	 * @return The loaded image
	 */
	private static Image loadImage(File file) {
		BufferedImage in = null;
		try {
			in = ImageIO.read(file);
		} catch (IOException e) {
			e.printStackTrace();
		}
		return in;
	}

	/**
	 * Load every PNG file inside the res/pieces directory.
	 * The filenames without extensions are used as keys in the map textures.
	 */
	private static void loadPieceTextures() {
		File	dir		= new File("res/pieces");
		File[]	files	= dir.listFiles((File parentDir, String name) -> name.toLowerCase().endsWith(".png"));
		for (File file : files)
			textures.put(file.getName().replaceFirst("[.][^.]+$", ""), TextureUtil.loadImage(file));
	}

}
